pub type BuildSender = Sender<BuildRequest>;Expand description
Sender half: TPC core sends build requests to the builder thread.
Aliased Type
pub struct BuildSender { /* private fields */ }pub type BuildSender = Sender<BuildRequest>;Sender half: TPC core sends build requests to the builder thread.
pub struct BuildSender { /* private fields */ }