pub enum DistanceError {
DimMismatch {
a_dim: usize,
b_dim: usize,
},
Dtype(DtypeError),
}Expand description
Error type for distance_typed.
Variants
DimMismatch
The two input buffers encode different numbers of dimensions.
Dtype(DtypeError)
A byte buffer has the wrong length for the given dtype and dim.