pub struct MultiVectorDoc {
pub doc_id: u32,
pub vectors: Vec<Vec<f32>>,
}Expand description
A document represented by one or more embedding vectors.
Fields
doc_id: u32vectors: Vec<Vec<f32>>Variable-length list of vectors. For Meta Token mode this has fixed length K.