Module routing

Module routing 

Filter routing decision tree for the vector query planner.

Given information about the query’s filter predicates, this module decides which execution path to use: brute-force scan, a pre-built SIEVE subindex, Compass IVF+B+-tree, or NaviX adaptive-local on the global graph.

Structs

FilterRouteInputs
Inputs to the filter routing decision tree.

Enums

FilterRoute
The execution path chosen by the filter router.

Functions

pick_quantization
Pick the best quantization tier for a given candidate set size and target recall requirement.
route_filter
Decide which execution path to use for this filtered vector query.