pub enum CodecName {
Sq8,
Pq,
Binary,
RaBitQ,
Bbq,
}Expand description
Identity tag for a rerank codec — used to detect mismatch when a search requests a different codec than the sidecar was built with.
Variants
Implementations