SieveRouter — routes a filtered ANN query to a specialized subindex when the predicate signature matches, or falls back to NaviX on the global index.
Structs
- Sieve
Router - Routes a filtered ANN query to the right index.
SieveRouter — routes a filtered ANN query to a specialized subindex when the predicate signature matches, or falls back to NaviX on the global index.